@@ -1,4 +1,4 @@
 #' @importFrom utils globalVariables
 utils::globalVariables(c("bin", "dist.b", "dist.g", "mod", "no", "pct.obs", "pct.y.sum",
 			 "sb", "sg", "so", "sy", "type", "woe", "x", "x.avg", 
-			 "x.max", "x.min", "y", "y.avg", "y.sum"))
\ No newline at end of file
+			 "x.max", "x.min", "y", "y.avg", "y.sum", "y.cs", "n.cs", "y.cs.rev", "n.cs.rev"))
\ No newline at end of file
